const path = require('path');
const fs = require('fs');

// 执行node命令时候的文件绝对路径
const root = process.cwd();

const argsReg = /^--[0-9a-zA-Z]+$/;

/**
 * 从根目录开始获取文件绝对地址路径
 * @param filePath 文件参数
 * @returns {string} 返回绝对路径
 */
function getProjectPath(...filePath) {
  return path.join(root, ...filePath);
}

function getParseArgsToJson() {
  const args = process.argv.slice(2);
  const result = {};
  const length = args.length;
  for (let count = 0; count < args.length; count++) {
    if (!length || count >= length) {
      break;
    }
    if (!argsReg.test(args[0])) {
      throw Error('Run args error, example: "--port 3030" or "--eslint"');
    }
    const currentItem = args[count];
    if (argsReg.test(currentItem)) {
      const key = currentItem.substring(2);
      if (count + 1 >= length) {
        result[key] = true;
        break;
      }
      const nextItem = args[count + 1];
      if (argsReg.test(nextItem)) {
        result[key] = true;
        continue;
      }
      result[key] = isNaN(Number(nextItem))
        ? nextItem === 'false'
          ? false
          : nextItem === 'true'
          ? true
          : nextItem
        : Number(nextItem);
    }
  }
  return result;
}

function isExistsSyncFile(currentPath) {
  return fs.existsSync(currentPath);
}

const parseArgsToJson = getParseArgsToJson();

function deleteFolders(currentPath) {
  let files = [];
  if (isExistsSyncFile(currentPath)) {
    files = fs.readdirSync(currentPath);
    files.forEach(file => {
      const curPath = `${currentPath}/${file}`;
      if (fs.statSync(curPath).isDirectory()) {
        deleteFolders(curPath);
      } else {
        fs.unlinkSync(curPath);
      }
    });
    fs.rmdirSync(currentPath);
  }
}

module.exports = {
  getProjectPath,
  parseArgsToJson,
  deleteFolders,
  isExistsSyncFile
};
